@@ -699,6 +699,10 @@ class Simulation(ABC):
         """ Configures/runs the model based on the specified
             simulation mode.
         """
+        # get absolute path
+        output_dir = os.path.expanduser(output_dir)
+        output_dir = os.path.abspath(output_dir)
+
         # check that the output directory exists and get the name/mode for the simulation
         output_dir = check_output_dir(output_dir)
         name, mode = starting_params()
